From 04a4cc64efc8d109c2bc41295952dc73b710fb7f Mon Sep 17 00:00:00 2001
From: Scott Snyder <scott.snyder@cern.ch>
Date: Tue, 21 Jun 2016 16:23:51 +0200
Subject: [PATCH] 'Fix clang warning (abs overload).' (TrigCostD3PD-00-02-16)

	* Tagging TrigCostD3PD-00-02-16.
	* Root/Utils.cxx: Fix clang warning (abs overload).
	* Tagging TrigCostD3PD-00-02-15.
	* TrigCostD3PD/TrigCostD3PDObject.h: Do not use using declaration
	in a header in the global namespace.
	* Tagging TrigCostD3PD-00-02-14.
	* Comply with ATLAS naming conventions.
	* Tagging TrigCostD3PD-00-02-13.
	* TrigCostD3PD/VarHandle.icc: Suppress cppcheck false positives.


Former-commit-id: efa12f2eef07d44da771eea28751a3efb6aba14a
---
 .../TrigCostD3PD/Root/NTUP_TRIGCOST.cxx       | 16 +--
 .../TrigCostD3PD/Root/TrigCostD3PDObject.cxx  | 54 +++++-----
 .../Root/TrigDBKeysD3PDObject.cxx             | 54 +++++-----
 .../TrigCostD3PD/Root/UserD3PDObject.cxx      | 88 ++++++++---------
 Trigger/TrigCost/TrigCostD3PD/Root/Utils.cxx  |  8 +-
 .../TrigCost/TrigCostD3PD/Root/VarHandle.cxx  | 72 +++++++-------
 .../TrigCostD3PD/TrigCostD3PD/NTUP_TRIGCOST.h |  4 +-
 .../TrigCostD3PD/TrigCostD3PDObject.h         |  7 +-
 .../TrigCostD3PD/TrigDBKeysD3PDObject.h       |  6 +-
 .../TrigCostD3PD/UserD3PDObject.h             | 20 ++--
 .../TrigCostD3PD/UserD3PDObject.icc           | 84 ++++++++--------
 .../TrigCostD3PD/TrigCostD3PD/VarHandle.h     | 26 ++---
 .../TrigCostD3PD/TrigCostD3PD/VarHandle.icc   | 98 ++++++++++---------
 .../TrigCostD3PD/TrigCostD3PD/VarProxy.h      |  6 +-
 .../TrigCostD3PD/TrigCostD3PD/VarProxy.icc    | 30 +++---
 15 files changed, 287 insertions(+), 286 deletions(-)

diff --git a/Trigger/TrigCost/TrigCostD3PD/Root/NTUP_TRIGCOST.cxx b/Trigger/TrigCost/TrigCostD3PD/Root/NTUP_TRIGCOST.cxx
index 96791211a1d..01315336d40 100644
--- a/Trigger/TrigCost/TrigCostD3PD/Root/NTUP_TRIGCOST.cxx
+++ b/Trigger/TrigCost/TrigCostD3PD/Root/NTUP_TRIGCOST.cxx
@@ -19,10 +19,10 @@ namespace D3PDReader {
 
    NTUP_TRIGCOST::NTUP_TRIGCOST()
       : D3PDObjectBase(),
-        TrigCostHLT( fEntry, "TrigCostHLT_" ),
-        trig_DB( fEntry, "trig_DB_" ),
-        fEntry( 0 ),
-        fFromInput( kTRUE ) {
+        TrigCostHLT( m_entry, "TrigCostHLT_" ),
+        trig_DB( m_entry, "trig_DB_" ),
+        m_entry( 0 ),
+        m_fromInput( kTRUE ) {
 
    }
 
@@ -30,8 +30,8 @@ namespace D3PDReader {
       : D3PDObjectBase(),
         TrigCostHLT( "TrigCostHLT_" ),
         trig_DB( "trig_DB_" ),
-        fEntry( 0 ),
-        fFromInput( kFALSE ) {
+        m_entry( 0 ),
+        m_fromInput( kFALSE ) {
 
    }
 
@@ -49,7 +49,7 @@ namespace D3PDReader {
 
    void NTUP_TRIGCOST::ReadFrom( ::TTree* tree ) {
 
-      if( ! fFromInput ) {
+      if( ! m_fromInput ) {
          Error( "ReadFrom", "Object can't read a D3PD. Use a different constructor!" );
          return;
       }
@@ -98,7 +98,7 @@ namespace D3PDReader {
 
    void NTUP_TRIGCOST::GetEntry( ::Long64_t entry ) {
 
-      fEntry = entry;
+      m_entry = entry;
       return;
    }
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/Root/UserD3PDObject.cxx b/Trigger/TrigCost/TrigCostD3PD/Root/UserD3PDObject.cxx
index 9437a839ec4..287a328621f 100644
--- a/Trigger/TrigCost/TrigCostD3PD/Root/UserD3PDObject.cxx
+++ b/Trigger/TrigCost/TrigCostD3PD/Root/UserD3PDObject.cxx
@@ -14,22 +14,22 @@ namespace D3PDReader {
 
    UserD3PDObjectElement::UserD3PDObjectElement( size_t index,
                                                  const UserD3PDObject& parent )
-      : ::TNamed(), fParent( &parent ), fIndex( index ), fProxies() {
+      : ::TNamed(), m_parent( &parent ), m_index( index ), m_proxies() {
 
    }
 
    UserD3PDObjectElement::
    UserD3PDObjectElement( const UserD3PDObjectElement& parent )
-      : TNamed( parent ), fParent( parent.fParent ), fIndex( parent.fIndex ),
-        fProxies() {
+      : TNamed( parent ), m_parent( parent.m_parent ), m_index( parent.m_index ),
+        m_proxies() {
 
    }
 
    UserD3PDObjectElement::~UserD3PDObjectElement() {
 
       // Delete the allocated objects:
-      std::map< ::TString, VarProxyBase* >::iterator itr = fProxies.begin();
-      std::map< ::TString, VarProxyBase* >::iterator end = fProxies.end();
+      std::map< ::TString, VarProxyBase* >::iterator itr = m_proxies.begin();
+      std::map< ::TString, VarProxyBase* >::iterator end = m_proxies.end();
       for( ; itr != end; ++itr ) {
          delete itr->second;
       }
@@ -37,36 +37,36 @@ namespace D3PDReader {
 
    size_t UserD3PDObjectElement::GetIndex() const {
 
-      return fIndex;
+      return m_index;
    }
 
    UserD3PDObject::UserD3PDObject( const ::Long64_t& master,
                                    const char* prefix )
-      : D3PDObjectBase(), fMaster( &master ), fPrefix( prefix ), fProxies(),
-        fHandles(), fExtraHandles(), fFromInput( kTRUE ),
-        fInTree( 0 ) {
+      : D3PDObjectBase(), m_master( &master ), m_prefix( prefix ), m_proxies(),
+        m_handles(), m_extraHandles(), m_fromInput( kTRUE ),
+        m_inTree( 0 ) {
 
    }
 
    UserD3PDObject::UserD3PDObject( const char* prefix )
-      : D3PDObjectBase(), fMaster( 0 ), fPrefix( prefix ), fProxies(),
-        fHandles(), fExtraHandles(), fFromInput( kFALSE ),
-        fInTree( 0 ) {
+      : D3PDObjectBase(), m_master( 0 ), m_prefix( prefix ), m_proxies(),
+        m_handles(), m_extraHandles(), m_fromInput( kFALSE ),
+        m_inTree( 0 ) {
 
    }
 
    UserD3PDObject::~UserD3PDObject() {
 
       // Delete the allocated objects:
-      std::map< ::TString, VarHandleBase* >::iterator itr = fHandles.begin();
-      std::map< ::TString, VarHandleBase* >::iterator end = fHandles.end();
+      std::map< ::TString, VarHandleBase* >::iterator itr = m_handles.begin();
+      std::map< ::TString, VarHandleBase* >::iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          delete itr->second;
       }
       // Although the code almost certainly crashes when such dummy objects
       // are created, there's still some chance that they need to be cleaned:
-      std::vector< VarHandleBase* >::iterator eitr = fExtraHandles.begin();
-      std::vector< VarHandleBase* >::iterator eend = fExtraHandles.end();
+      std::vector< VarHandleBase* >::iterator eitr = m_extraHandles.begin();
+      std::vector< VarHandleBase* >::iterator eend = m_extraHandles.end();
       for( ; eitr != eend; ++eitr ) {
          delete *eitr;
       }
@@ -77,7 +77,7 @@ namespace D3PDReader {
     */
    const char* UserD3PDObject::GetPrefix() const {
 
-      return fPrefix;
+      return m_prefix;
    }
 
    /**
@@ -85,11 +85,11 @@ namespace D3PDReader {
     */
    void UserD3PDObject::SetPrefix( const char* prefix ) {
 
-      fPrefix = prefix;
+      m_prefix = prefix;
 
       // Set all the variable names:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->SetName( ::TString( prefix ) + itr->first );
       }
@@ -106,7 +106,7 @@ namespace D3PDReader {
    void UserD3PDObject::ReadFrom( TTree* tree ) {
 
       // Check if the object will be able to read from the TTree:
-      if( ! fFromInput ) {
+      if( ! m_fromInput ) {
          Error( "ReadFrom",
                 "The object was not created with the correct" );
          Error( "ReadFrom",
@@ -115,8 +115,8 @@ namespace D3PDReader {
       }
 
       // Call ReadFrom(...) on all the variables:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          // Ignore the variables that are created only now:
          if( ! itr->second->GetMaster() ) continue;
@@ -124,7 +124,7 @@ namespace D3PDReader {
       }
 
       // Remember the pointer:
-      fInTree = tree;
+      m_inTree = tree;
 
       return;
    }
@@ -139,8 +139,8 @@ namespace D3PDReader {
    void UserD3PDObject::WriteTo( TTree* tree ) {
 
       // Call WriteTo(...) on all the variables:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->WriteTo( tree );
       }
@@ -163,10 +163,10 @@ namespace D3PDReader {
 
       ::TPRegexp re( pattern );
 
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
-         if( ! re.Match( fPrefix + itr->first ) ) continue;
+         if( ! re.Match( m_prefix + itr->first ) ) continue;
          if( active ) {
             if( itr->second->IsAvailable() ) itr->second->SetActive( active );
          } else {
@@ -186,7 +186,7 @@ namespace D3PDReader {
    void UserD3PDObject::ReadAllActive() {
 
       // Check if it makes sense to call this function:
-      if( ! fFromInput ) {
+      if( ! m_fromInput ) {
          static ::Bool_t wPrinted = kFALSE;
          if( ! wPrinted ) {
             Warning( "ReadAllActive",
@@ -198,8 +198,8 @@ namespace D3PDReader {
       }
 
       // Read in the current entry for each active variable:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          if( ! itr->second->IsActive() ) continue;
          itr->second->ReadCurrentEntry();
@@ -222,8 +222,8 @@ namespace D3PDReader {
    //    D3PDReadStats result;
 
    //    // Add the statistics from each variable to the result:
-   //    std::map< ::TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-   //    std::map< ::TString, VarHandleBase* >::const_iterator end = fHandles.end();
+   //    std::map< ::TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+   //    std::map< ::TString, VarHandleBase* >::const_iterator end = m_handles.end();
    //    for( ; itr != end; ++itr ) {
    //       result.AddVariable( itr->second->GetStatistics() );
    //    }
@@ -236,7 +236,7 @@ namespace D3PDReader {
     */
    UserD3PDObject& UserD3PDObject::Set( const UserD3PDObject& parent ) {
 
-      if( parent.fHandles.size() ) {
+      if( parent.m_handles.size() ) {
          Error( "Set",
                 "User variables can not be copied usig this function!" );
       }
@@ -256,8 +256,8 @@ namespace D3PDReader {
    void UserD3PDObject::Clear( Option_t* ) {
 
       // Clear each variable:
-      std::map< ::TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< ::TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< ::TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< ::TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->Clear();
       }
@@ -270,7 +270,7 @@ namespace D3PDReader {
     */
    UserD3PDObject& UserD3PDObject::Add( const UserD3PDObjectElement& el ) {
 
-      if( el.fProxies.size() ) {
+      if( el.m_proxies.size() ) {
          Error( "Add",
                 "User variables can not be copied usig this function!" );
       }
@@ -289,10 +289,10 @@ namespace D3PDReader {
     */
    UserD3PDObjectElement& UserD3PDObject::operator[]( size_t index ) {
 
-      while( fProxies.size() <= index ) {
-         fProxies.push_back( new UserD3PDObjectElement( fProxies.size(), *this ) );
+      while( m_proxies.size() <= index ) {
+         m_proxies.push_back( new UserD3PDObjectElement( m_proxies.size(), *this ) );
       }
-      return *fProxies[ index ];
+      return *m_proxies[ index ];
    }
 
    /**
@@ -306,10 +306,10 @@ namespace D3PDReader {
     */
    const UserD3PDObjectElement& UserD3PDObject::operator[]( size_t index ) const {
 
-      while( fProxies.size() <= index ) {
-         fProxies.push_back( new UserD3PDObjectElement( fProxies.size(), *this ) );
+      while( m_proxies.size() <= index ) {
+         m_proxies.push_back( new UserD3PDObjectElement( m_proxies.size(), *this ) );
       }
-      return *fProxies[ index ];
+      return *m_proxies[ index ];
    }
 
    /**
diff --git a/Trigger/TrigCost/TrigCostD3PD/Root/Utils.cxx b/Trigger/TrigCost/TrigCostD3PD/Root/Utils.cxx
index 83d7d238f11..96cbdc13748 100644
--- a/Trigger/TrigCost/TrigCostD3PD/Root/Utils.cxx
+++ b/Trigger/TrigCost/TrigCostD3PD/Root/Utils.cxx
@@ -129,13 +129,13 @@ namespace D3PDReader {
     */
    ::TString SizeToString( ::Long64_t bytes ) {
 
-      if( ::fabs( bytes ) > 1e12 ) {
+      if( std::abs( bytes ) > 1e12 ) {
          return ::TString::Format( "%g TB", bytes * 1e-12 );
-      } else if( ::fabs( bytes ) > 1e9 ) {
+      } else if( std::abs( bytes ) > 1e9 ) {
          return ::TString::Format( "%g GB", bytes * 1e-9 );
-      } else if( ::fabs( bytes ) > 1e6 ) {
+      } else if( std::abs( bytes ) > 1e6 ) {
          return ::TString::Format( "%g MB", bytes * 1e-6 );
-      } else if( ::fabs( bytes ) > 1e3 ) {
+      } else if( std::abs( bytes ) > 1e3 ) {
          return ::TString::Format( "%g kB", bytes * 1e-3 );
       } else {
          return ::TString::Format( "%lli bytes", bytes );
diff --git a/Trigger/TrigCost/TrigCostD3PD/Root/VarHandle.cxx b/Trigger/TrigCost/TrigCostD3PD/Root/VarHandle.cxx
index 5121f3ffcdd..0173a2460b7 100644
--- a/Trigger/TrigCost/TrigCostD3PD/Root/VarHandle.cxx
+++ b/Trigger/TrigCost/TrigCostD3PD/Root/VarHandle.cxx
@@ -15,10 +15,10 @@ namespace D3PDReader {
 
    VarHandleBase::VarHandleBase( const char* name,
                                  const ::Long64_t* master )
-      : fMaster( master ), fFromInput( kFALSE ),
-        fInTree( 0 ), fInBranch( 0 ), fAvailable( UNKNOWN ), fName( name ),
-        fActive( kFALSE ), fType( "" ),
-        fEntriesRead(), fBranchSize(), fZippedSize() {
+      : m_master( master ), m_fromInput( kFALSE ),
+        m_inTree( 0 ), m_inBranch( 0 ), m_available( UNKNOWN ), m_name( name ),
+        m_active( kFALSE ), m_type( "" ),
+        m_entriesRead(), m_branchSize(), m_zippedSize() {
 
 #ifdef COLLECT_D3PD_READING_STATISTICS
       //D3PDPerfStats::Instance();
@@ -27,52 +27,52 @@ namespace D3PDReader {
 
    const char* VarHandleBase::GetName() const {
 
-      return fName;
+      return m_name;
    }
 
    void VarHandleBase::SetName( const char* name ) {
 
-      fName = name;
+      m_name = name;
       return;
    }
 
    const char* VarHandleBase::GetType() const {
 
-      return fType;
+      return m_type;
    }
 
    void VarHandleBase::SetType( const char* type ) {
 
-      fType = type;
+      m_type = type;
       return;
    }
 
    const ::Long64_t* VarHandleBase::GetMaster() const {
 
-      return fMaster;
+      return m_master;
    }
 
    void VarHandleBase::SetMaster( const ::Long64_t* master ) {
 
-      fMaster = master;
+      m_master = master;
       return;
    }
 
    ::Bool_t VarHandleBase::IsActive() const {
 
-      return fActive;
+      return m_active;
    }
 
    void VarHandleBase::SetActive( ::Bool_t active ) {
 
-      fActive = active;
+      m_active = active;
       return;
    }
 
    ::Bool_t VarHandleBase::IsAvailable() const {
 
-      if( ! fFromInput ) return kTRUE;
-      switch( fAvailable ) {
+      if( ! m_fromInput ) return kTRUE;
+      switch( m_available ) {
 
       case AVAILABLE:
          return kTRUE;
@@ -82,9 +82,9 @@ namespace D3PDReader {
          break;
       case UNKNOWN:
          {
-            if( ! fInTree ) return kTRUE;
+            if( ! m_inTree ) return kTRUE;
             ::Bool_t temp = kFALSE;
-            fAvailable = ( temp = fInTree->GetBranch( GetName() ) ) ? AVAILABLE :
+            m_available = ( temp = m_inTree->GetBranch( GetName() ) ) ? AVAILABLE :
                          UNAVAILABLE;
             return temp;
          }
@@ -104,29 +104,29 @@ namespace D3PDReader {
    //    ::Long64_t readEntries = 0;
    //    ::Long64_t unzippedBytes = 0;
    //    ::Long64_t zippedBytes = 0;
-   //    for( size_t i = 0; i < fEntriesRead.size(); ++i ) { 
-   //       readEntries += fEntriesRead[ i ];
-   //       unzippedBytes += static_cast< ::Long64_t >( fBranchSize[ i ] *
-   //                                                   fEntriesRead[ i ] );
-   //       zippedBytes += static_cast< ::Long64_t >( fZippedSize[ i ] *
-   //                                                 fEntriesRead[ i ] );
+   //    for( size_t i = 0; i < m_entriesRead.size(); ++i ) { 
+   //       readEntries += m_entriesRead[ i ];
+   //       unzippedBytes += static_cast< ::Long64_t >( m_branchSize[ i ] *
+   //                                                   m_entriesRead[ i ] );
+   //       zippedBytes += static_cast< ::Long64_t >( m_zippedSize[ i ] *
+   //                                                 m_entriesRead[ i ] );
    //    }
 
    //    // Now return the "smart" object:
    //    return VariableStats( GetName(), GetType(),
-   //                          fEntriesRead.size(), readEntries,
+   //                          m_entriesRead.size(), readEntries,
    //                          unzippedBytes, zippedBytes );
    // }
 
    ::Bool_t VarHandleBase::ConnectVariable( void* var, ::TClass* realClass,
                                             EDataType dtype, Bool_t isptr ) const {
 
-      if( ! fInTree ) {
+      if( ! m_inTree ) {
          ::Error( "D3PDReader::VarHandleBase::ConnectVariable",
                   "Object not connected yet!" );
          return kFALSE;
       }
-      if( ! fInTree->GetBranch( GetName() ) ) {
+      if( ! m_inTree->GetBranch( GetName() ) ) {
          ::Error( "D3PDReader::VarHandleBase::ConnectVariable",
                   "The following variable doesn't exist: %s",
                   GetName() );
@@ -134,9 +134,9 @@ namespace D3PDReader {
       }
 #ifdef ACTIVATE_BRANCHES
       // Only call this function when the user asks for it. It's quite expensive...
-      fInTree->SetBranchStatus( ::TString( GetName() ) + "*", 1 );
+      m_inTree->SetBranchStatus( ::TString( GetName() ) + "*", 1 );
 #endif // ACTIVATE_BRANCHES
-      if( fInTree->SetBranchAddress( GetName(), var, &fInBranch,
+      if( m_inTree->SetBranchAddress( GetName(), var, &m_inBranch,
                                      realClass, dtype, isptr ) ) {
          ::Error( "D3PDReader::VarHandleBase::ConnectVariable",
                   "Couldn't connect variable to branch: %s", GetName() );
@@ -144,7 +144,7 @@ namespace D3PDReader {
       }
 
 #ifdef COLLECT_D3PD_READING_STATISTICS
-      //UpdateStat( fInBranch );
+      //UpdateStat( m_inBranch );
 #endif // COLLECT_D3PD_READING_STATISTICS
 
       return kTRUE;
@@ -152,12 +152,12 @@ namespace D3PDReader {
 
    void VarHandleBase::UpdateBranch() const {
       //Cov warning
-      if (!fInBranch) return;
+      if (!m_inBranch) return;
 
-      if( *fMaster != fInBranch->GetReadEntry() ) {
-         fInBranch->GetEntry( *fMaster );
+      if( *m_master != m_inBranch->GetReadEntry() ) {
+         m_inBranch->GetEntry( *m_master );
 #ifdef COLLECT_D3PD_READING_STATISTICS
-        // ++( fEntriesRead.back() );
+        // ++( m_entriesRead.back() );
 #endif // COLLECT_D3PD_READING_STATISTICS
       }
 
@@ -166,13 +166,13 @@ namespace D3PDReader {
 
    // void VarHandleBase::UpdateStat( ::TBranch* br ) const {
 
-   //    fEntriesRead.push_back( 0 );
-   //    fBranchSize.push_back( ( ::Float_t ) br->GetTotalSize( "*" ) /
+   //    m_entriesRead.push_back( 0 );
+   //    m_branchSize.push_back( ( ::Float_t ) br->GetTotalSize( "*" ) /
    //                           ( ::Float_t ) br->GetEntries() );
-   //    fZippedSize.push_back( ( ::Float_t ) br->GetZipBytes( "*" ) /
+   //    m_zippedSize.push_back( ( ::Float_t ) br->GetZipBytes( "*" ) /
    //                           ( ::Float_t ) br->GetEntries() );
 
-   //    D3PDPerfStats::Instance()->NewTreeAccessed( fInTree );
+   //    D3PDPerfStats::Instance()->NewTreeAccessed( m_inTree );
 
    //    return;
    // }
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/NTUP_TRIGCOST.h b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/NTUP_TRIGCOST.h
index da86d107073..a759ee9a5ca 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/NTUP_TRIGCOST.h
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/NTUP_TRIGCOST.h
@@ -63,8 +63,8 @@ namespace D3PDReader {
       TrigDBKeysD3PDObject trig_DB;
 
    private:
-      Long64_t fEntry; ///< Variable storing the current entry number
-      Bool_t fFromInput; ///< Flag specifying if object is used for D3PD reading
+      Long64_t m_entry; ///< Variable storing the current entry number
+      Bool_t m_fromInput; ///< Flag specifying if object is used for D3PD reading
 
       ClassDef( NTUP_TRIGCOST, 0 )
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/TrigCostD3PDObject.h b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/TrigCostD3PDObject.h
index 590ee9b96da..e4ce74f86c6 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/TrigCostD3PDObject.h
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/TrigCostD3PDObject.h
@@ -15,7 +15,6 @@
 // STL include(s):
 #include <map>
 #include <vector>
-using std::vector;
 
 // ROOT include(s):
 #include <TObject.h>
@@ -222,9 +221,9 @@ namespace D3PDReader {
       /// Function setting up all the VarHandle members
       void SetVarHandles( const ::Long64_t* master );
 
-      std::map< ::TString, VarHandleBase* > fHandles; ///< Book-keeper of the VarHandle members
-      const ::Bool_t fFromInput; ///< Flag specifying if object is used for D3PD reading
-      ::TString fPrefix; ///< Prefix to the branch names
+      std::map< ::TString, VarHandleBase* > m_handles; ///< Book-keeper of the VarHandle members
+      const ::Bool_t m_fromInput; ///< Flag specifying if object is used for D3PD reading
+      ::TString m_prefix; ///< Prefix to the branch names
 
       ClassDef( TrigCostD3PDObject, 0 )
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/TrigDBKeysD3PDObject.h b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/TrigDBKeysD3PDObject.h
index 1d49436848f..59cba60fbf7 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/TrigDBKeysD3PDObject.h
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/TrigDBKeysD3PDObject.h
@@ -78,9 +78,9 @@ namespace D3PDReader {
       /// Function setting up all the VarHandle members
       void SetVarHandles( const ::Long64_t* master );
 
-      std::map< ::TString, VarHandleBase* > fHandles; ///< Book-keeper of the VarHandle members
-      const ::Bool_t fFromInput; ///< Flag specifying if object is used for D3PD reading
-      ::TString fPrefix; ///< Prefix to the branch names
+      std::map< ::TString, VarHandleBase* > m_handles; ///< Book-keeper of the VarHandle members
+      const ::Bool_t m_fromInput; ///< Flag specifying if object is used for D3PD reading
+      ::TString m_prefix; ///< Prefix to the branch names
 
       ClassDef( TrigDBKeysD3PDObject, 0 )
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/UserD3PDObject.h b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/UserD3PDObject.h
index aa01eac7443..8fbf2bbced9 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/UserD3PDObject.h
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/UserD3PDObject.h
@@ -74,11 +74,11 @@ namespace D3PDReader {
 
    private:
       /// Reference to the parent of this object
-      const UserD3PDObject* fParent;
+      const UserD3PDObject* m_parent;
       /// The index of this object inside the parent container
-      size_t fIndex;
+      size_t m_index;
       /// Book-keeper of the VarProxy members
-      mutable std::map< ::TString, VarProxyBase* > fProxies;
+      mutable std::map< ::TString, VarProxyBase* > m_proxies;
 
       UserD3PDObjectElement& operator=( const UserD3PDObjectElement& parent );
 
@@ -159,18 +159,18 @@ namespace D3PDReader {
       const VarHandle< T >& Variable( const TString& name ) const;
 
    private:
-      const ::Long64_t* fMaster; ///< Pointer to the master entry number
-      ::TString fPrefix; ///< Prefix to the branch names
+      const ::Long64_t* m_master; ///< Pointer to the master entry number
+      ::TString m_prefix; ///< Prefix to the branch names
       ///< Internal list of proxy objects
-      mutable std::vector< UserD3PDObjectElement* > fProxies;
+      mutable std::vector< UserD3PDObjectElement* > m_proxies;
       /// Book-keeper of the VarHandle members
-      mutable std::map< ::TString, VarHandleBase* > fHandles;
+      mutable std::map< ::TString, VarHandleBase* > m_handles;
       /// Book-keeper of VarHandle objects needed for technical reasons
-      mutable std::vector< VarHandleBase* > fExtraHandles;
+      mutable std::vector< VarHandleBase* > m_extraHandles;
       /// Flag specifying if object is used for D3PD reading
-      const ::Bool_t fFromInput;
+      const ::Bool_t m_fromInput;
       /// TTree that is being read currently
-      ::TTree* fInTree;
+      ::TTree* m_inTree;
 
       ClassDef( UserD3PDObject, 0 )
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/UserD3PDObject.icc b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/UserD3PDObject.icc
index 4cde33d8bde..f034ce35b1f 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/UserD3PDObject.icc
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/UserD3PDObject.icc
@@ -33,8 +33,8 @@ namespace D3PDReader {
 
       // Try to find the variable:
       std::map< ::TString, VarProxyBase* >::const_iterator itr =
-         fProxies.find( name );
-      if( itr != fProxies.end() ) {
+         m_proxies.find( name );
+      if( itr != m_proxies.end() ) {
          // If it's already known, let's see if it's the right type:
          VarProxy< T >* result =
             dynamic_cast< VarProxy< T >* >( itr->second );
@@ -42,9 +42,9 @@ namespace D3PDReader {
             // Create a dummy object. The code will crash soon
             // anyway...
             VarProxy< T >* dummy =
-               new VarProxy< T >( fParent->Variable< std::vector< T >* >( name ),
-                                  fIndex );
-            fProxies[ name ] = dummy;
+               new VarProxy< T >( m_parent->Variable< std::vector< T >* >( name ),
+                                  m_index );
+            m_proxies[ name ] = dummy;
             // Tell the user what happened:
             Error( "Variable",
                    "Variable with name '%s' requested with wrong type",
@@ -53,11 +53,11 @@ namespace D3PDReader {
          }
          // Check if the underlying vector is large enough:
          const VarHandle< std::vector< T >* >& vh = 
-            fParent->Variable< std::vector< T >* >( name );
+            m_parent->Variable< std::vector< T >* >( name );
          if( vh.IsAvailable() && ( ! vh.GetMaster() ) &&
-             ( vh()->size() <= fIndex ) ) {
-            UserD3PDObject* ncparent = const_cast< UserD3PDObject* >( fParent );
-            ncparent->Variable< std::vector< T >* >( name )()->resize( fIndex + 1 );
+             ( vh()->size() <= m_index ) ) {
+            UserD3PDObject* ncparent = const_cast< UserD3PDObject* >( m_parent );
+            ncparent->Variable< std::vector< T >* >( name )()->resize( m_index + 1 );
          }
          // Return the proxy:
          return *result;
@@ -65,17 +65,17 @@ namespace D3PDReader {
 
       // Add the new proxy variable:
       VarProxy< T >* result =
-         new VarProxy< T >( fParent->Variable< std::vector< T >* >( name ),
-                            fIndex );
-      fProxies[ name ] = result;
+         new VarProxy< T >( m_parent->Variable< std::vector< T >* >( name ),
+                            m_index );
+      m_proxies[ name ] = result;
 
       // Check if the underlying vector is large enough:
       const VarHandle< std::vector< T >* >& vh = 
-         fParent->Variable< std::vector< T >* >( name );
+         m_parent->Variable< std::vector< T >* >( name );
       if( vh.IsAvailable() && ( ! vh.GetMaster() ) &&
-          ( vh()->size() <= fIndex ) ) {
-         UserD3PDObject* ncparent = const_cast< UserD3PDObject* >( fParent );
-         ncparent->Variable< std::vector< T >* >( name )()->resize( fIndex + 1 );
+          ( vh()->size() <= m_index ) ) {
+         UserD3PDObject* ncparent = const_cast< UserD3PDObject* >( m_parent );
+         ncparent->Variable< std::vector< T >* >( name )()->resize( m_index + 1 );
       }
 
       // Return the proxy:
@@ -101,8 +101,8 @@ namespace D3PDReader {
 
       // Try to find the variable:
       std::map< ::TString, VarProxyBase* >::const_iterator itr =
-         fProxies.find( name );
-      if( itr != fProxies.end() ) {
+         m_proxies.find( name );
+      if( itr != m_proxies.end() ) {
          // If it's already known, let's see if it's the right type:
          VarProxy< T >* result =
             dynamic_cast< VarProxy< T >* >( itr->second );
@@ -110,9 +110,9 @@ namespace D3PDReader {
             // Create a dummy object. The code will crash soon
             // anyway...
             VarProxy< T >* dummy =
-               new VarProxy< T >( fParent->Variable< std::vector< T >* >( name ),
-                                  fIndex );
-            fProxies[ name ] = dummy;
+               new VarProxy< T >( m_parent->Variable< std::vector< T >* >( name ),
+                                  m_index );
+            m_proxies[ name ] = dummy;
             // Tell the user what happened:
             Error( "Variable",
                    "Variable with name '%s' requested with wrong type",
@@ -125,9 +125,9 @@ namespace D3PDReader {
 
       // Add the new proxy variable:
       VarProxy< T >* result =
-         new VarProxy< T >( fParent->Variable< std::vector< T >* >( name ),
-                            fIndex );
-      fProxies[ name ] = result;
+         new VarProxy< T >( m_parent->Variable< std::vector< T >* >( name ),
+                            m_index );
+      m_proxies[ name ] = result;
 
       // Return the proxy:
       return *result;
@@ -145,16 +145,16 @@ namespace D3PDReader {
 
       // Check if the variable with this name is already in place:
       std::map< ::TString, VarHandleBase* >::const_iterator itr =
-         fHandles.find( name );
-      if( itr != fHandles.end() ) {
+         m_handles.find( name );
+      if( itr != m_handles.end() ) {
          Warning( "DeclareVariable",
                   "Variable with name '%s' already declared",
-                  ( fPrefix + name ).Data() );
+                  ( m_prefix + name ).Data() );
          return;
       }
 
       // Declare the new variable:
-      fHandles[ name ] = new VarHandle< T >( fPrefix + name, 0 );
+      m_handles[ name ] = new VarHandle< T >( m_prefix + name, 0 );
 
       return;
    }
@@ -172,8 +172,8 @@ namespace D3PDReader {
 
       // Try to find the variable:
       std::map< ::TString, VarHandleBase* >::const_iterator itr =
-         fHandles.find( name );
-      if( itr != fHandles.end() ) {
+         m_handles.find( name );
+      if( itr != m_handles.end() ) {
          // It's already known, so let's see if it's of the right type:
          VarHandle< T >* result =
             dynamic_cast< VarHandle< T >* >( itr->second );
@@ -181,12 +181,12 @@ namespace D3PDReader {
             // Add a dummy object for technical reasons. The user code
             // will anyway probably die after this.
             VarHandle< T >* dummy = new VarHandle< T >();
-            fExtraHandles.push_back( dummy );
+            m_extraHandles.push_back( dummy );
             // Tell the user what happened:
             Error( "Variable",
                    "Variable with name '%s' is of type '%s', "
                    "not of type '%s'",
-                   ( fPrefix + name ).Data(), itr->second->GetType(),
+                   ( m_prefix + name ).Data(), itr->second->GetType(),
                    dummy->GetType() );
             // Return the dummy:
             return *dummy;
@@ -196,9 +196,9 @@ namespace D3PDReader {
       }
 
       // If it doesn't exist yet, let's add it:
-      VarHandle< T >* result = new VarHandle< T >( fPrefix + name, fMaster );
-      if( fInTree ) result->ReadFrom( fInTree );
-      fHandles[ name ] = result;
+      VarHandle< T >* result = new VarHandle< T >( m_prefix + name, m_master );
+      if( m_inTree ) result->ReadFrom( m_inTree );
+      m_handles[ name ] = result;
       return *result;
    }
 
@@ -214,8 +214,8 @@ namespace D3PDReader {
 
       // Try to find the variable:
       std::map< ::TString, VarHandleBase* >::const_iterator itr =
-         fHandles.find( name );
-      if( itr != fHandles.end() ) {
+         m_handles.find( name );
+      if( itr != m_handles.end() ) {
          // It's already known, so let's see if it's of the right type:
          VarHandle< T >* result =
             dynamic_cast< VarHandle< T >* >( itr->second );
@@ -223,12 +223,12 @@ namespace D3PDReader {
             // Add a dummy object for technical reasons. The user code
             // will anyway probably die after this.
             VarHandle< T >* dummy = new VarHandle< T >();
-            fExtraHandles.push_back( dummy );
+            m_extraHandles.push_back( dummy );
             // Tell the user what happened:
             Error( "Variable",
                    "Variable with name '%s' is of type '%s', "
                    "not of type '%s'",
-                   ( fPrefix + name ).Data(), itr->second->GetType(),
+                   ( m_prefix + name ).Data(), itr->second->GetType(),
                    dummy->GetType() );
             // Return the dummy:
             return *dummy;
@@ -238,9 +238,9 @@ namespace D3PDReader {
       }
 
       // If it doesn't exist yet, let's add it:
-      VarHandle< T >* result = new VarHandle< T >( fPrefix + name, fMaster );
-      if( fInTree ) result->ReadFrom( fInTree );
-      fHandles[ name ] = result;
+      VarHandle< T >* result = new VarHandle< T >( m_prefix + name, m_master );
+      if( m_inTree ) result->ReadFrom( m_inTree );
+      m_handles[ name ] = result;
       return *result;
    }
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarHandle.h b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarHandle.h
index 6a034e994ee..243e09ce81e 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarHandle.h
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarHandle.h
@@ -97,20 +97,20 @@ namespace D3PDReader {
       /// Translate the typeid() type name to a huma-readable ROOT type name
       const char* RootCppType( const char* typeid_type ) const;
 
-      const ::Long64_t* fMaster; ///< Pointer to the current entry number
-      ::Bool_t fFromInput; ///< Flag showing if the variable is read from an input TTree
-      ::TTree* fInTree; ///< The input TTree
-      mutable ::TBranch* fInBranch; /// The input branch belonging to this variable
-      mutable BranchAvailability fAvailable; ///< Availability of the branch
+      const ::Long64_t* m_master; ///< Pointer to the current entry number
+      ::Bool_t m_fromInput; ///< Flag showing if the variable is read from an input TTree
+      ::TTree* m_inTree; ///< The input TTree
+      mutable ::TBranch* m_inBranch; /// The input branch belonging to this variable
+      mutable BranchAvailability m_available; ///< Availability of the branch
 
    private:
-      ::TString fName; ///< Name of the branch to handle
-      ::Bool_t fActive; ///< Flag telling if the variable can be written to the output
+      ::TString m_name; ///< Name of the branch to handle
+      ::Bool_t m_active; ///< Flag telling if the variable can be written to the output
 
-      ::TString fType; ///< Variable type
-      mutable std::vector< ::Long64_t > fEntriesRead; ///< Number of read entries for each tree
-      mutable std::vector< ::Float_t > fBranchSize; ///< Unzipped entry size for each tree
-      mutable std::vector< ::Float_t > fZippedSize; ///< Zipped entry size for each tree
+      ::TString m_type; ///< Variable type
+      mutable std::vector< ::Long64_t > m_entriesRead; ///< Number of read entries for each tree
+      mutable std::vector< ::Float_t > m_branchSize; ///< Unzipped entry size for each tree
+      mutable std::vector< ::Float_t > m_zippedSize; ///< Zipped entry size for each tree
 
    }; // class VarHandleBase
 
@@ -160,7 +160,7 @@ namespace D3PDReader {
       void Set( Type value );
 
    private:
-      mutable Type fVariable; ///< The variable in memory
+      mutable Type m_variable; ///< The variable in memory
 
    }; // class VarHandle
 
@@ -211,7 +211,7 @@ namespace D3PDReader {
       void Set( const_result_type value );
 
    private:
-      mutable Type* fVariable; ///< The variable in memory
+      mutable Type* m_variable; ///< The variable in memory
 
    }; // class VarHandle
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarHandle.icc b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarHandle.icc
index 866c52daf4a..c5c45b58dde 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarHandle.icc
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarHandle.icc
@@ -23,10 +23,11 @@
 namespace D3PDReader {
 
    template< typename Type >
+   // cppcheck-suppress uninitMemberVar
    VarHandle< Type >::VarHandle( const char* name,
                                  const ::Long64_t* master )
       : VarHandleBase( name, master ),
-        fVariable() {
+        m_variable() {
 
       SetType( RootCppType( typeid( Type ).name() ) );
    }
@@ -39,11 +40,11 @@ namespace D3PDReader {
    template< typename Type >
    void VarHandle< Type >::ReadFrom( ::TTree* tree ) {
 
-      fInTree = tree;
-      fFromInput = kTRUE;
-      fVariable = 0;
-      fInBranch = 0;
-      fAvailable = UNKNOWN;
+      m_inTree = tree;
+      m_fromInput = kTRUE;
+      m_variable = 0;
+      m_inBranch = 0;
+      m_available = UNKNOWN;
 
       return;
    }
@@ -56,7 +57,7 @@ namespace D3PDReader {
       ::TBranch* branch = tree->GetBranch( GetName() );
       if( branch ) return branch;
 
-      branch = tree->Branch( GetName(), &fVariable,
+      branch = tree->Branch( GetName(), &m_variable,
                              ::TString::Format( "%s/%s", GetName(),
                                                 RootType( typeid( Type ).name() ) ) );
       if( ! branch ) {
@@ -75,39 +76,39 @@ namespace D3PDReader {
    template< typename Type >
    typename VarHandle< Type >::result_type VarHandle< Type >::operator()() {
 
-      if( ! fFromInput ) return fVariable;
+      if( ! m_fromInput ) return m_variable;
 
-      if( ! fInBranch ) {
-         if( ! ConnectVariable( &fVariable, TClass::GetClass( typeid( Type ) ),
+      if( ! m_inBranch ) {
+         if( ! ConnectVariable( &m_variable, TClass::GetClass( typeid( Type ) ),
                                 TDataType::GetType( typeid( Type ) ), kFALSE ) ||
-             !fInBranch )
+             !m_inBranch )
          {
             ::Error( ::TString( "D3PDReader::VarHandle::" ) + GetName() + "()",
                      "Failed connecting to D3PD" );
-            return fVariable;
+            return m_variable;
          }
       }
       UpdateBranch();
 
-      return fVariable;
+      return m_variable;
    }
 
    template< typename Type >
    typename VarHandle< Type >::const_result_type VarHandle< Type >::operator()() const {
 
-      if( ! fFromInput ) return fVariable;
+      if( ! m_fromInput ) return m_variable;
 
-      if( ! fInBranch ) {
-         if( ! ConnectVariable( &fVariable, TClass::GetClass( typeid( Type ) ),
+      if( ! m_inBranch ) {
+         if( ! ConnectVariable( &m_variable, TClass::GetClass( typeid( Type ) ),
                                 TDataType::GetType( typeid( Type ) ), kFALSE ) ) {
             ::Error( ::TString( "D3PDReader::VarHandle::" ) + GetName() + "()",
                      "Failed connecting to D3PD" );
-            return fVariable;
+            return m_variable;
          }
       }
       UpdateBranch();
 
-      return fVariable;
+      return m_variable;
    }
 
    template< typename Type >
@@ -116,7 +117,7 @@ namespace D3PDReader {
       if( IsAvailable() ) {
          this->operator()();
       } else {
-         fVariable = 0;
+         m_variable = 0;
       }
       return;
    }
@@ -131,15 +132,16 @@ namespace D3PDReader {
    template< typename Type >
    void VarHandle< Type >::Set( Type value ) {
 
-      fVariable = value;
+      m_variable = value;
       return;
    }
 
    template< typename Type >
+   // cppcheck-suppress uninitMemberVar
    VarHandle< Type* >::VarHandle( const char* name,
                                   const ::Long64_t* master )
       : VarHandleBase( name, master ),
-        fVariable( 0 ) {
+        m_variable( 0 ) {
 
       int status;
       char* type_name = abi::__cxa_demangle( typeid( Type ).name(), 0, 0, &status );
@@ -152,17 +154,17 @@ namespace D3PDReader {
    template< typename Type >
    VarHandle< Type* >::~VarHandle() {
 
-      if( fVariable ) delete fVariable;
+      if( m_variable ) delete m_variable;
    }
 
    template< typename Type >
    void VarHandle< Type* >::ReadFrom( ::TTree* tree ) {
 
-      fInTree = tree;
-      fFromInput = kTRUE;
-      if( fVariable ) fVariable->clear();
-      fInBranch = 0;
-      fAvailable = UNKNOWN;
+      m_inTree = tree;
+      m_fromInput = kTRUE;
+      if( m_variable ) m_variable->clear();
+      m_inBranch = 0;
+      m_available = UNKNOWN;
 
       return;
    }
@@ -181,10 +183,10 @@ namespace D3PDReader {
                   typeid( Type ).name() );
          return 0;
       }
-      if( ! fVariable ) {
-         fVariable = new Type();
+      if( ! m_variable ) {
+         m_variable = new Type();
       }
-      branch = tree->Bronch( GetName(), GetType(), &fVariable );
+      branch = tree->Bronch( GetName(), GetType(), &m_variable );
       if( ! branch ) {
          ::Error( "D3PDReader::VarHandle::WriteTo",
                   "Couldn't add variable %s to tree %s",
@@ -202,46 +204,46 @@ namespace D3PDReader {
    typename VarHandle< Type* >::result_type
    VarHandle< Type* >::operator()() {
 
-      if( ! fFromInput ) {
-         if( ! fVariable ) fVariable = new Type();
-         return fVariable;
+      if( ! m_fromInput ) {
+         if( ! m_variable ) m_variable = new Type();
+         return m_variable;
       }
 
-      if( ! fInBranch ) {
-         if( ! ConnectVariable( &fVariable, TClass::GetClass( typeid( Type ) ),
+      if( ! m_inBranch ) {
+         if( ! ConnectVariable( &m_variable, TClass::GetClass( typeid( Type ) ),
                                 TDataType::GetType( typeid( Type ) ), kTRUE ) ) {
             ::Error( ::TString( "D3PDReader::VarHandle::" ) + GetName() + "()",
                      "Failed connecting to D3PD" );
-            return fVariable;
+            return m_variable;
          }
       }
       UpdateBranch();
 
-      return fVariable;
+      return m_variable;
    }
 
    template< typename Type >
    typename VarHandle< Type* >::const_result_type
    VarHandle< Type* >::operator()() const {
 
-      if( ! fFromInput ) {
-         if( ! fVariable ) fVariable = new Type();
-         return fVariable;
+      if( ! m_fromInput ) {
+         if( ! m_variable ) m_variable = new Type();
+         return m_variable;
       }
 
-      if( ! fInBranch ) {
-         if( ! ConnectVariable( &fVariable, TClass::GetClass( typeid( Type ) ),
+      if( ! m_inBranch ) {
+         if( ! ConnectVariable( &m_variable, TClass::GetClass( typeid( Type ) ),
                                 TDataType::GetType( typeid( Type ) ), kTRUE ) ||
-             !fInBranch)
+             !m_inBranch)
          {
             ::Error( ::TString( "D3PDReader::VarHandle::" ) + GetName() + "()",
                      "Failed connecting to D3PD" );
-            return fVariable;
+            return m_variable;
          }
       }
       UpdateBranch();
 
-      return fVariable;
+      return m_variable;
    }
 
    template< typename Type >
@@ -250,8 +252,8 @@ namespace D3PDReader {
       if( IsAvailable() ) {
          this->operator()();
       } else {
-         if( ! fVariable ) fVariable = new Type();
-         fVariable->clear();
+         if( ! m_variable ) m_variable = new Type();
+         m_variable->clear();
       }
       return;
    }
@@ -266,7 +268,7 @@ namespace D3PDReader {
    template< typename Type >
    void VarHandle< Type* >::Set( const_result_type value ) {
 
-      *fVariable = *value;
+      *m_variable = *value;
       return;
    }
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarProxy.h b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarProxy.h
index 6bb26fc8b35..bc6f71c5113 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarProxy.h
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarProxy.h
@@ -74,9 +74,9 @@ namespace D3PDReader {
       const_result_type operator()() const;
 
    private:
-      VarHandle< std::vector< Type >* >* fHandle; ///< Pointer to the handle object
-      size_t fIndex; ///< Index inside the handle object's vector
-      Type fDummy; ///< Object returned by default
+      VarHandle< std::vector< Type >* >* m_handle; ///< Pointer to the handle object
+      size_t m_index; ///< Index inside the handle object's vector
+      Type m_dummy; ///< Object returned by default
 
    }; // class VarProxy
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarProxy.icc b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarProxy.icc
index c01d7df5be0..7ab1c65f9df 100644
--- a/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarProxy.icc
+++ b/Trigger/TrigCost/TrigCostD3PD/TrigCostD3PD/VarProxy.icc
@@ -16,23 +16,23 @@ namespace D3PDReader {
    template< typename Type >
    VarProxy< Type >::VarProxy( const VarHandle< std::vector< Type >* >& handle,
                                size_t i )
-      : fHandle( const_cast< VarHandle< std::vector< Type >* >* >( &handle ) ),
-        fIndex( i ), fDummy() {
+      : m_handle( const_cast< VarHandle< std::vector< Type >* >* >( &handle ) ),
+        m_index( i ), m_dummy() {
 
    }
 
    template< typename Type >
    VarProxy< Type >::VarProxy( const VarProxy< Type >& parent )
-      : VarProxyBase(), fHandle( parent.fHandle ), fIndex( parent.fIndex ),
-        fDummy() {
+      : VarProxyBase(), m_handle( parent.m_handle ), m_index( parent.m_index ),
+        m_dummy() {
 
    }
 
    template< typename Type >
    VarProxy< Type >& VarProxy< Type >::operator=( const VarProxy< Type >& parent ) {
 
-      fHandle = parent.fHandle;
-      fIndex  = parent.fIndex;
+      m_handle = parent.m_handle;
+      m_index  = parent.m_index;
 
       return *this;
    }
@@ -40,30 +40,30 @@ namespace D3PDReader {
    template< typename Type >
    ::Bool_t VarProxy< Type >::IsAvailable() const {
 
-      return fHandle->IsAvailable();
+      return m_handle->IsAvailable();
    }
 
    template< typename Type >
    typename VarProxy< Type >::result_type VarProxy< Type >::operator()() {
 
-      if( fHandle->IsAvailable() ) {
-         return ( ( *( *fHandle )() ) )[ fIndex ];
+      if( m_handle->IsAvailable() ) {
+         return ( ( *( *m_handle )() ) )[ m_index ];
       } else {
-         ::Warning( ::TString( "D3PDReader::VarProxy::" ) + fHandle->GetName() + "()",
+         ::Warning( ::TString( "D3PDReader::VarProxy::" ) + m_handle->GetName() + "()",
                     "Variable not available on input. Returning 0" );
-         return fDummy;
+         return m_dummy;
       }
    }
 
    template< typename Type >
    typename VarProxy< Type >::const_result_type VarProxy< Type >::operator()() const {
 
-      if( fHandle->IsAvailable() ) {
-         return ( ( *( *fHandle )() ) )[ fIndex ];
+      if( m_handle->IsAvailable() ) {
+         return ( ( *( *m_handle )() ) )[ m_index ];
       } else {
-         ::Warning( ::TString( "D3PDReader::VarProxy::" ) + fHandle->GetName() + "()",
+         ::Warning( ::TString( "D3PDReader::VarProxy::" ) + m_handle->GetName() + "()",
                     "Variable not available on input. Returning 0" );
-         return fDummy;
+         return m_dummy;
       }
    }
 
diff --git a/Trigger/TrigCost/TrigCostD3PD/Root/TrigCostD3PDObject.cxx b/Trigger/TrigCost/TrigCostD3PD/Root/TrigCostD3PDObject.cxx
index 4df53c3e397..70c5b52afb5 100644
--- a/Trigger/TrigCost/TrigCostD3PD/Root/TrigCostD3PDObject.cxx
+++ b/Trigger/TrigCost/TrigCostD3PD/Root/TrigCostD3PDObject.cxx
@@ -30,9 +30,9 @@ namespace D3PDReader {
     */
    TrigCostD3PDObject::TrigCostD3PDObject( const ::Long64_t& master, const char* prefix )
       : UserD3PDObject( master, prefix ),
-        fHandles(),
-        fFromInput( kTRUE ),
-        fPrefix( prefix ) {
+        m_handles(),
+        m_fromInput( kTRUE ),
+        m_prefix( prefix ) {
 
       SetVarHandles( &master );
    }
@@ -46,9 +46,9 @@ namespace D3PDReader {
     */
    TrigCostD3PDObject::TrigCostD3PDObject( const char* prefix )
       : UserD3PDObject( prefix ),
-        fHandles(),
-        fFromInput( kFALSE ),
-        fPrefix( prefix ) {
+        m_handles(),
+        m_fromInput( kFALSE ),
+        m_prefix( prefix ) {
 
       SetVarHandles( 0 );
    }
@@ -58,7 +58,7 @@ namespace D3PDReader {
     */
    const char* TrigCostD3PDObject::GetPrefix() const {
 
-      return fPrefix;
+      return m_prefix;
    }
 
    /**
@@ -70,11 +70,11 @@ namespace D3PDReader {
       UserD3PDObject::SetPrefix( prefix );
 
       // Remember the prefix:
-      fPrefix = prefix;
+      m_prefix = prefix;
 
       // Set all the variable names:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->SetName( ::TString( prefix ) + itr->first );
       }
@@ -91,7 +91,7 @@ namespace D3PDReader {
    void TrigCostD3PDObject::ReadFrom( TTree* tree ) {
 
       // Check if the object will be able to read from the TTree:
-      if( ! fFromInput ) {
+      if( ! m_fromInput ) {
          Error( "ReadFrom", "The object was not created with the correct" );
          Error( "ReadFrom", "constructor to read data from a D3PD!" );
          return;
@@ -101,8 +101,8 @@ namespace D3PDReader {
       UserD3PDObject::ReadFrom( tree );
 
       // Call ReadFrom(...) on all the variables:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->ReadFrom( tree );
       }
@@ -123,8 +123,8 @@ namespace D3PDReader {
       UserD3PDObject::WriteTo( tree );
 
       // Call WriteTo(...) on all the variables:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->WriteTo( tree );
       }
@@ -150,10 +150,10 @@ namespace D3PDReader {
 
       ::TPRegexp re( pattern );
 
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
-         if( ! re.Match( fPrefix + itr->first ) ) continue;
+         if( ! re.Match( m_prefix + itr->first ) ) continue;
          if( active ) {
             if( itr->second->IsAvailable() ) itr->second->SetActive( active );
          } else {
@@ -173,7 +173,7 @@ namespace D3PDReader {
    void TrigCostD3PDObject::ReadAllActive() {
 
       // Check if it makes sense to call this function:
-      if( ! fFromInput ) {
+      if( ! m_fromInput ) {
          static ::Bool_t wPrinted = kFALSE;
          if( ! wPrinted ) {
             Warning( "ReadAllActive", "Function only meaningful when used on objects" );
@@ -186,8 +186,8 @@ namespace D3PDReader {
       UserD3PDObject::ReadAllActive();
 
       // Read in the current entry for each active variable:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          if( ! itr->second->IsActive() ) continue;
          itr->second->ReadCurrentEntry();
@@ -210,8 +210,8 @@ namespace D3PDReader {
    //    D3PDReadStats result = UserD3PDObject::GetStatistics();
 
    //    // Add the statistics from each variable to the result:
-   //    std::map< ::TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-   //    std::map< ::TString, VarHandleBase* >::const_iterator end = fHandles.end();
+   //    std::map< ::TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+   //    std::map< ::TString, VarHandleBase* >::const_iterator end = m_handles.end();
    //    for( ; itr != end; ++itr ) {
    //       result.AddVariable( itr->second->GetStatistics() );
    //    }
@@ -231,7 +231,7 @@ namespace D3PDReader {
    TrigCostD3PDObject& TrigCostD3PDObject::Set( const TrigCostD3PDObject& parent ) {
 
       // Check if this function can be used on the object:
-      if( fFromInput ) {
+      if( m_fromInput ) {
          Error( "Set", "Objects used for reading a D3PD can't be modified!" );
          return *this;
       }
@@ -1436,12 +1436,12 @@ namespace D3PDReader {
          { "timerTrigCost", "timerTrigCost" }
       };
 
       // Set up the fHandles map using this list:
       for( Int_t i = 0; i < NVARNAMES; ++i ) {
          VarHandleBase* vh = GetVarHandle( VARNAMES[ i ][ 0 ] );
-         vh->SetName( fPrefix + VARNAMES[ i ][ 1 ] );
+         vh->SetName( m_prefix + VARNAMES[ i ][ 1 ] );
          vh->SetMaster( master );
-         fHandles[ VARNAMES[ i ][ 0 ] ] = vh;
+         m_handles[ VARNAMES[ i ][ 0 ] ] = vh;
       }
 
       return;
@@ -1436,12 +1436,12 @@ namespace D3PDReader {
       };
 
-      // Set up the fHandles map using this list:
+      // Set up the m_handles map using this list:
       for( Int_t i = 0; i < NVARNAMES; ++i ) {
          VarHandleBase* vh = GetVarHandle( VARNAMES[ i ][ 0 ] );
diff --git a/Trigger/TrigCost/TrigCostD3PD/Root/TrigDBKeysD3PDObject.cxx b/Trigger/TrigCost/TrigCostD3PD/Root/TrigDBKeysD3PDObject.cxx
index f9dd5d9ae79..ca0d18230b9 100644
--- a/Trigger/TrigCost/TrigCostD3PD/Root/TrigDBKeysD3PDObject.cxx
+++ b/Trigger/TrigCost/TrigCostD3PD/Root/TrigDBKeysD3PDObject.cxx
@@ -30,9 +30,9 @@ namespace D3PDReader {
     */
    TrigDBKeysD3PDObject::TrigDBKeysD3PDObject( const ::Long64_t& master, const char* prefix )
       : UserD3PDObject( master, prefix ),
-        fHandles(),
-        fFromInput( kTRUE ),
-        fPrefix( prefix ) {
+        m_handles(),
+        m_fromInput( kTRUE ),
+        m_prefix( prefix ) {
 
       SetVarHandles( &master );
    }
@@ -46,9 +46,9 @@ namespace D3PDReader {
     */
    TrigDBKeysD3PDObject::TrigDBKeysD3PDObject( const char* prefix )
       : UserD3PDObject( prefix ),
-        fHandles(),
-        fFromInput( kFALSE ),
-        fPrefix( prefix ) {
+        m_handles(),
+        m_fromInput( kFALSE ),
+        m_prefix( prefix ) {
 
       SetVarHandles( 0 );
    }
@@ -58,7 +58,7 @@ namespace D3PDReader {
     */
    const char* TrigDBKeysD3PDObject::GetPrefix() const {
 
-      return fPrefix;
+      return m_prefix;
    }
 
    /**
@@ -70,11 +70,11 @@ namespace D3PDReader {
       UserD3PDObject::SetPrefix( prefix );
 
       // Remember the prefix:
-      fPrefix = prefix;
+      m_prefix = prefix;
 
       // Set all the variable names:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->SetName( ::TString( prefix ) + itr->first );
       }
@@ -91,7 +91,7 @@ namespace D3PDReader {
    void TrigDBKeysD3PDObject::ReadFrom( TTree* tree ) {
 
       // Check if the object will be able to read from the TTree:
-      if( ! fFromInput ) {
+      if( ! m_fromInput ) {
          Error( "ReadFrom", "The object was not created with the correct" );
          Error( "ReadFrom", "constructor to read data from a D3PD!" );
          return;
@@ -101,8 +101,8 @@ namespace D3PDReader {
       UserD3PDObject::ReadFrom( tree );
 
       // Call ReadFrom(...) on all the variables:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->ReadFrom( tree );
       }
@@ -123,8 +123,8 @@ namespace D3PDReader {
       UserD3PDObject::WriteTo( tree );
 
       // Call WriteTo(...) on all the variables:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          itr->second->WriteTo( tree );
       }
@@ -150,10 +150,10 @@ namespace D3PDReader {
 
       ::TPRegexp re( pattern );
 
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
-         if( ! re.Match( fPrefix + itr->first ) ) continue;
+         if( ! re.Match( m_prefix + itr->first ) ) continue;
          if( active ) {
             if( itr->second->IsAvailable() ) itr->second->SetActive( active );
          } else {
@@ -173,7 +173,7 @@ namespace D3PDReader {
    void TrigDBKeysD3PDObject::ReadAllActive() {
 
       // Check if it makes sense to call this function:
-      if( ! fFromInput ) {
+      if( ! m_fromInput ) {
          static ::Bool_t wPrinted = kFALSE;
          if( ! wPrinted ) {
             Warning( "ReadAllActive", "Function only meaningful when used on objects" );
@@ -186,8 +186,8 @@ namespace D3PDReader {
       UserD3PDObject::ReadAllActive();
 
       // Read in the current entry for each active variable:
-      std::map< TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-      std::map< TString, VarHandleBase* >::const_iterator end = fHandles.end();
+      std::map< TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+      std::map< TString, VarHandleBase* >::const_iterator end = m_handles.end();
       for( ; itr != end; ++itr ) {
          if( ! itr->second->IsActive() ) continue;
          itr->second->ReadCurrentEntry();
@@ -210,8 +210,8 @@ namespace D3PDReader {
    //    D3PDReadStats result = UserD3PDObject::GetStatistics();
 
    //    // Add the statistics from each variable to the result:
-   //    std::map< ::TString, VarHandleBase* >::const_iterator itr = fHandles.begin();
-   //    std::map< ::TString, VarHandleBase* >::const_iterator end = fHandles.end();
+   //    std::map< ::TString, VarHandleBase* >::const_iterator itr = m_handles.begin();
+   //    std::map< ::TString, VarHandleBase* >::const_iterator end = m_handles.end();
    //    for( ; itr != end; ++itr ) {
    //       result.AddVariable( itr->second->GetStatistics() );
    //    }
@@ -231,7 +231,7 @@ namespace D3PDReader {
    TrigDBKeysD3PDObject& TrigDBKeysD3PDObject::Set( const TrigDBKeysD3PDObject& parent ) {
 
       // Check if this function can be used on the object:
-      if( fFromInput ) {
+      if( m_fromInput ) {
          Error( "Set", "Objects used for reading a D3PD can't be modified!" );
          return *this;
       }
@@ -301,12 +301,12 @@ namespace D3PDReader {
          { "SMK", "SMK" }
       };
 
       // Set up the fHandles map using this list:
       for( Int_t i = 0; i < NVARNAMES; ++i ) {
          VarHandleBase* vh = GetVarHandle( VARNAMES[ i ][ 0 ] );
-         vh->SetName( fPrefix + VARNAMES[ i ][ 1 ] );
+         vh->SetName( m_prefix + VARNAMES[ i ][ 1 ] );
          vh->SetMaster( master );
-         fHandles[ VARNAMES[ i ][ 0 ] ] = vh;
+         m_handles[ VARNAMES[ i ][ 0 ] ] = vh;
       }
 
       return;
@@ -301,12 +301,12 @@ namespace D3PDReader {
       };
 
-      // Set up the fHandles map using this list:
+      // Set up the m_handles map using this list:
       for( Int_t i = 0; i < NVARNAMES; ++i ) {
          VarHandleBase* vh = GetVarHandle( VARNAMES[ i ][ 0 ] );
-- 
GitLab